var class_ogre_1_1_scene_manager =
[
    [ "Listener", "class_ogre_1_1_scene_manager_1_1_listener.html", "class_ogre_1_1_scene_manager_1_1_listener" ],
    [ "RenderContext", "struct_ogre_1_1_scene_manager_1_1_render_context.html", "struct_ogre_1_1_scene_manager_1_1_render_context" ],
    [ "AnimationIterator", "class_ogre_1_1_scene_manager.html#a3a720414f68274bb9c5026911e27135d", null ],
    [ "CameraIterator", "class_ogre_1_1_scene_manager.html#a460e50da4b97d1beaef1a64bfa039928", null ],
    [ "MovableObjectIterator", "class_ogre_1_1_scene_manager.html#af5348867645ff727d1ca25dd89795376", null ],
    [ "MovableObjectVec", "class_ogre_1_1_scene_manager.html#a6d8f5f81e262b6347f5066da27d6fe70", null ],
    [ "SceneNodeList", "class_ogre_1_1_scene_manager.html#a8f87c38314b272fff95da3065f3740ee", null ],
    [ "EnvFeatures", "class_ogre_1_1_scene_manager.html#a4f9ec83967af47028ae2731ccf9884af", [
      [ "EnvFeatures_DiffuseGiFromReflectionProbe", "class_ogre_1_1_scene_manager.html#a4f9ec83967af47028ae2731ccf9884afac3479b832ae356b1073e1bd3fb5370b6", null ]
    ] ],
    [ "IlluminationRenderStage", "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827", [
      [ "IRS_NONE", "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8fd3e7fb8fab382a9d29e6e081ae556a", null ],
      [ "IRS_RENDER_TO_TEXTURE", "class_ogre_1_1_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8f99da7404ae8c16199dde8d34367b1a", null ]
    ] ],
    [ "PrefabType", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbf", [
      [ "PT_PLANE", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbfaf0fb654fb98508a564c17d3d5b2feee3", null ],
      [ "PT_CUBE", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbfa25b0181d24b783ab75da2520305d292a", null ],
      [ "PT_SPHERE", "class_ogre_1_1_scene_manager.html#ab4c2ff4f6c76f7fe0a8eae76f2a84cbfa0f94148c2cfe190f3ea04374af220eba", null ]
    ] ],
    [ "SkyMethod", "class_ogre_1_1_scene_manager.html#a6a925e073eee8e57dafc08083bc10238", [
      [ "SkyCubemap", "class_ogre_1_1_scene_manager.html#a6a925e073eee8e57dafc08083bc10238a3f37d0605dbc3f2486d858105b6eae7d", null ],
      [ "SkyEquirectangular", "class_ogre_1_1_scene_manager.html#a6a925e073eee8e57dafc08083bc10238af0ca6a31afce4f654de4e9ee2cc90162", null ]
    ] ],
    [ "SceneManager", "class_ogre_1_1_scene_manager.html#aeeb8be4e1344e25b015eca559096ada5", null ],
    [ "~SceneManager", "class_ogre_1_1_scene_manager.html#a6c8b9108b44339a321bc69b25a0c0a1a", null ],
    [ "_addAutotrackingSceneNode", "class_ogre_1_1_scene_manager.html#a9f0b98113bf8c46fc2413f09326b9c9e", null ],
    [ "_addCompositorTexture", "class_ogre_1_1_scene_manager.html#a9203e12ebfaec54ed988e3b0a523ee3c", null ],
    [ "_addWireAabb", "class_ogre_1_1_scene_manager.html#a9a9c54dae09ee2532723cb2d5632be24", null ],
    [ "_applySceneAnimations", "class_ogre_1_1_scene_manager.html#aa80de6aa83eaaad929a73061c24bc2fa", null ],
    [ "_areRenderStateChangesSuppressed", "class_ogre_1_1_scene_manager.html#a561f511a98d8a4537c5343d07ee4352d", null ],
    [ "_calculateCurrentCastersBox", "class_ogre_1_1_scene_manager.html#a245b17763b78ee37c0c281209c43cefd", null ],
    [ "_collectForwardPlusObjects", "class_ogre_1_1_scene_manager.html#a2e915f183603082a83e314967555ac55", null ],
    [ "_createCubemapProbe", "class_ogre_1_1_scene_manager.html#af7bc9d19d31025a52fd76389066ab418", null ],
    [ "_createSceneNode", "class_ogre_1_1_scene_manager.html#a1f068bf536a1b910aa5cd02e55165f35", null ],
    [ "_createTagPoint", "class_ogre_1_1_scene_manager.html#a344584fef03521706592a140a8884b2d", null ],
    [ "_cullPhase01", "class_ogre_1_1_scene_manager.html#ae809ab7de35a8947b1d196006a17720e", null ],
    [ "_destroyAllCubemapProbes", "class_ogre_1_1_scene_manager.html#a5f939d39028792c0b38811d734758baf", null ],
    [ "_destroyCubemapProbe", "class_ogre_1_1_scene_manager.html#a1cca7941525cf1c3aa08a6e3dfa5357a", null ],
    [ "_frameEnded", "class_ogre_1_1_scene_manager.html#a88574ace95c8fcc5ede8c5e81a7ae83b", null ],
    [ "_getActivePassForwardPlus", "class_ogre_1_1_scene_manager.html#a5056240756e3528ad95e8caaad7e2765", null ],
    [ "_getAutoParamDataSource", "class_ogre_1_1_scene_manager.html#acc0c6f67ccef3d2bf3fae0569b54e500", null ],
    [ "_getCombinedVisibilityMask", "class_ogre_1_1_scene_manager.html#a280eb49f87f05d662135aadd4221fefc", null ],
    [ "_getCurrentRenderStage", "class_ogre_1_1_scene_manager.html#aaa36e203e1ba3eeab880e4c51a51efae", null ],
    [ "_getEntityMemoryManager", "class_ogre_1_1_scene_manager.html#aabc9effdee88bf684de9409d5d01caab", null ],
    [ "_getLightMemoryManager", "class_ogre_1_1_scene_manager.html#a48b9b48d600e83c4463e961a0585cba4", null ],
    [ "_getNodeMemoryManager", "class_ogre_1_1_scene_manager.html#a73f753de4c3a5bf22daf3da16d3b7e27", null ],
    [ "_getTagPointNodeMemoryManager", "class_ogre_1_1_scene_manager.html#af669a83b9010d5cb88c86084a28fd23e", null ],
    [ "_getTmpVisibleObjectsList", "class_ogre_1_1_scene_manager.html#ad195206ee14121a1850dcc3e2f98c15c", null ],
    [ "_handleLodEvents", "class_ogre_1_1_scene_manager.html#a72e39912a34617ffa0455f859ec438c3", null ],
    [ "_markGpuParamsDirty", "class_ogre_1_1_scene_manager.html#ac631d25ab65e821544835bfa1b507fc2", null ],
    [ "_notifyEntityMaterialLodChanged", "class_ogre_1_1_scene_manager.html#a272d1a76e7854e51f824f0099a4910cf", null ],
    [ "_notifyEntityMeshLodChanged", "class_ogre_1_1_scene_manager.html#ad0a84e6426cad7dfd721fb5fccd9976c", null ],
    [ "_notifyMovableObjectLodChanged", "class_ogre_1_1_scene_manager.html#ae4b6a7748dc4273fd6c160fb162c544f", null ],
    [ "_pauseRendering", "class_ogre_1_1_scene_manager.html#ad44e83cb8c1379a2b6bd0a19e37c695b", null ],
    [ "_releaseManualHardwareResources", "class_ogre_1_1_scene_manager.html#af4a61278b3ac74c9e16a7ba9cb45815b", null ],
    [ "_removeAutotrackingSceneNode", "class_ogre_1_1_scene_manager.html#a75673d9890a711b6de478ddab53d1aa9", null ],
    [ "_removeCompositorTextures", "class_ogre_1_1_scene_manager.html#a351700ac72df07006c59e1aa07dded7c", null ],
    [ "_removeSkeletonDef", "class_ogre_1_1_scene_manager.html#abba23854a544b95806bd737a8ffb49dc", null ],
    [ "_removeWireAabb", "class_ogre_1_1_scene_manager.html#adadb06373ea8f59dc573bfd1d8e03713", null ],
    [ "_renderPhase02", "class_ogre_1_1_scene_manager.html#aa5ad9929a1eee24fb63bddf1a7b074d4", null ],
    [ "_renderSingleObject", "class_ogre_1_1_scene_manager.html#ae32663cfb04485c2643a24a1240240c2", null ],
    [ "_restoreManualHardwareResources", "class_ogre_1_1_scene_manager.html#a315288f34c602a3242edfe13354748bc", null ],
    [ "_resumeRendering", "class_ogre_1_1_scene_manager.html#a27f763bb92fef8b1238e2272889ba58d", null ],
    [ "_setAtmosphere", "class_ogre_1_1_scene_manager.html#ae57a38bd2f7b48366ccd62ef42e7d72f", null ],
    [ "_setCamerasInProgress", "class_ogre_1_1_scene_manager.html#a9899cd0badfaa70088d4a27b8592eb82", null ],
    [ "_setCurrentCompositorPass", "class_ogre_1_1_scene_manager.html#acdd809e69cbbc4b565a27b8edef98ad1", null ],
    [ "_setCurrentRenderStage", "class_ogre_1_1_scene_manager.html#a77f751eb7bce6624985c304f878d51d9", null ],
    [ "_setCurrentShadowNode", "class_ogre_1_1_scene_manager.html#aa23534c58043177bd98177efc3b0f34c", null ],
    [ "_setDestinationRenderSystem", "class_ogre_1_1_scene_manager.html#ab20c0ee49a853145d3350e6e32c59f32", null ],
    [ "_setForwardPlusEnabledInPass", "class_ogre_1_1_scene_manager.html#a507d273b53104fb5b8c835bc0c7ce73a", null ],
    [ "_setLightCullingVisibility", "class_ogre_1_1_scene_manager.html#aa484c6a44eaae0ec7ce646b51d6dc8c3", null ],
    [ "_setPrePassMode", "class_ogre_1_1_scene_manager.html#a7de1de8fc1c2168416ed4fcd94639a74", null ],
    [ "_setRefractions", "class_ogre_1_1_scene_manager.html#a9c12be4929f32f819b60801c0d93ab9a", null ],
    [ "_suppressRenderStateChanges", "class_ogre_1_1_scene_manager.html#a6753ea2b52715774b7fdd59da232917a", null ],
    [ "_updateWorkerThread", "class_ogre_1_1_scene_manager.html#a9959c0abe638bebd7ad2a30abc23ca2e", null ],
    [ "_warmUpShaders", "class_ogre_1_1_scene_manager.html#a452210f8cda18ae14867bb1d637e1ff6", null ],
    [ "addListener", "class_ogre_1_1_scene_manager.html#a6b54e34b6a8e72d4c1456bda016731ad", null ],
    [ "addLodListener", "class_ogre_1_1_scene_manager.html#a2ac761cb112de51be26c54609de3c83a", null ],
    [ "addRenderObjectListener", "class_ogre_1_1_scene_manager.html#ab73819442f7f3540f52431064e6b1a97", null ],
    [ "addRenderQueueListener", "class_ogre_1_1_scene_manager.html#ae60242c5d130f884cd605d3393186df6", null ],
    [ "clearFrameData", "class_ogre_1_1_scene_manager.html#ae6382cdc89b215c451fc68e6a1cf2278", null ],
    [ "clearScene", "class_ogre_1_1_scene_manager.html#a01ba0aad5090ed0a8ff5e9c3d24fa924", null ],
    [ "createAABBQuery", "class_ogre_1_1_scene_manager.html#aba7931f453bc3e6ce2d340b62265973c", null ],
    [ "createAnimation", "class_ogre_1_1_scene_manager.html#aa9509d9c69659cfa5ee4a09532e461ea", null ],
    [ "createAnimationState", "class_ogre_1_1_scene_manager.html#acb6fa0098e1afd82a2eafb8d3fd21867", null ],
    [ "createBillboardChain", "class_ogre_1_1_scene_manager.html#af2d4879678c141d5acd892a4188aa221", null ],
    [ "createBillboardSet", "class_ogre_1_1_scene_manager.html#a6d0bb29f8f112dd2e6949a072d70c9ca", null ],
    [ "createCamera", "class_ogre_1_1_scene_manager.html#a406c35260ee06d3886218ad0c0f6134c", null ],
    [ "createDecal", "class_ogre_1_1_scene_manager.html#a593eb235e1bac27f6929cbf9025055c4", null ],
    [ "createEntity", "class_ogre_1_1_scene_manager.html#af5714312a90c6f699d901ca41933ee6a", null ],
    [ "createEntity", "class_ogre_1_1_scene_manager.html#a991078aae17f059537e8306cb8f9de02", null ],
    [ "createEntity", "class_ogre_1_1_scene_manager.html#a942371c3418e00862e25e3038b8c34dc", null ],
    [ "createIntersectionQuery", "class_ogre_1_1_scene_manager.html#a330ae308e614a06f201e1c460014b8c7", null ],
    [ "createItem", "class_ogre_1_1_scene_manager.html#a2e241b0afc26f04733c70e7c453b8787", null ],
    [ "createItem", "class_ogre_1_1_scene_manager.html#aff2ceebf9755716d814d867e810e0269", null ],
    [ "createLight", "class_ogre_1_1_scene_manager.html#a7399c836bf57186f171f4eb456c7fe4d", null ],
    [ "createManualObject", "class_ogre_1_1_scene_manager.html#a58defccc8c64e751db9b32a51c39c916", null ],
    [ "createMovableObject", "class_ogre_1_1_scene_manager.html#a70456cfbc5e944ab3e98e8d725e6f761", null ],
    [ "createParticleSystem", "class_ogre_1_1_scene_manager.html#a59388cb293d8e36f47b81aaddc1c5bd8", null ],
    [ "createParticleSystem", "class_ogre_1_1_scene_manager.html#afbbf975d14a09242a72e002109360fb2", null ],
    [ "createPlaneBoundedVolumeQuery", "class_ogre_1_1_scene_manager.html#a87acee4fb506a3dc869c674e6a2f19c8", null ],
    [ "createRayQuery", "class_ogre_1_1_scene_manager.html#a6b529b255c44117ca18a9cb43d46a2cc", null ],
    [ "createRectangle2D", "class_ogre_1_1_scene_manager.html#a785bf3dd77c0215e59b073d490387383", null ],
    [ "createRibbonTrail", "class_ogre_1_1_scene_manager.html#ab691852fd8c9335dba95a67661629b2c", null ],
    [ "createSceneNode", "class_ogre_1_1_scene_manager.html#a6e3a146e09708d7fab2536db8ddd7f36", null ],
    [ "createSkeletonInstance", "class_ogre_1_1_scene_manager.html#a5fdfd9e790d2630ce07fffd8fb5a84f1", null ],
    [ "createSphereQuery", "class_ogre_1_1_scene_manager.html#ab50462941a082ff4ff4f90b4d2f99009", null ],
    [ "createTagPoint", "class_ogre_1_1_scene_manager.html#ab289e99dd8aad3fd80deccfc93eb60b3", null ],
    [ "createWireAabb", "class_ogre_1_1_scene_manager.html#af799e7b51fb404a358944fe63ab7672a", null ],
    [ "cullLights", "class_ogre_1_1_scene_manager.html#a97b975559cf03c869e70fdcbe38c07ce", null ],
    [ "defragmentMemoryPools", "class_ogre_1_1_scene_manager.html#ad6bdefcfe64f080519d42f7082c232c1", null ],
    [ "destroyAllAnimations", "class_ogre_1_1_scene_manager.html#a7c69befc9541ac1d62f8514444ab4382", null ],
    [ "destroyAllAnimationStates", "class_ogre_1_1_scene_manager.html#a7d1f49ae1e1beaa6016873ecf13d2086", null ],
    [ "destroyAllBillboardChains", "class_ogre_1_1_scene_manager.html#ac1e639ded8260661408b498f041d701d", null ],
    [ "destroyAllBillboardSets", "class_ogre_1_1_scene_manager.html#a2c020b93723f94cb548a6656bb550e75", null ],
    [ "destroyAllCameras", "class_ogre_1_1_scene_manager.html#aaeca6aaeb426c53e5f740fca5d3acbf3", null ],
    [ "destroyAllDecals", "class_ogre_1_1_scene_manager.html#abfc21872f05d867b3f8c38cf67b0798c", null ],
    [ "destroyAllEntities", "class_ogre_1_1_scene_manager.html#aecdd88484a39195a9e3537923c2bf267", null ],
    [ "destroyAllItems", "class_ogre_1_1_scene_manager.html#aa542fb518afb5f148d6aa3a4c26bc75e", null ],
    [ "destroyAllLights", "class_ogre_1_1_scene_manager.html#a8047e4aab5a8991410e0ec32c21dedc7", null ],
    [ "destroyAllManualObjects", "class_ogre_1_1_scene_manager.html#a90caaf7b2618f1c17acf7799fc9f8cd2", null ],
    [ "destroyAllMovableObjects", "class_ogre_1_1_scene_manager.html#afc6593e55115bf3780865d9477a0654a", null ],
    [ "destroyAllMovableObjectsByType", "class_ogre_1_1_scene_manager.html#a8aca5477f30dd55321a101f25c6a5ee2", null ],
    [ "destroyAllParticleSystems", "class_ogre_1_1_scene_manager.html#a653364760a4df8af5c2d0d6511fb91b7", null ],
    [ "destroyAllRectangle2D", "class_ogre_1_1_scene_manager.html#acd0f342e3cc683f7bcbe15d1ddbce5b3", null ],
    [ "destroyAllRibbonTrails", "class_ogre_1_1_scene_manager.html#a4801c38cb6be7c6a761ae996dc7d9993", null ],
    [ "destroyAllWireAabbs", "class_ogre_1_1_scene_manager.html#a489fcdb9a59e542a0a09be7bdac2a2ef", null ],
    [ "destroyAnimation", "class_ogre_1_1_scene_manager.html#a7ac4e76d36c8f059d7389bf1233563b5", null ],
    [ "destroyAnimationState", "class_ogre_1_1_scene_manager.html#a22a3f58bff113aaac870c18741f7cd76", null ],
    [ "destroyBillboardChain", "class_ogre_1_1_scene_manager.html#a570a5bfc2b2285cf38974dc82db416c9", null ],
    [ "destroyBillboardSet", "class_ogre_1_1_scene_manager.html#af46af31e3f0a9a4c88eb755b9af885d4", null ],
    [ "destroyCamera", "class_ogre_1_1_scene_manager.html#acac58e45f8b6b6826c81933f02a45046", null ],
    [ "destroyDecal", "class_ogre_1_1_scene_manager.html#aba18ce869e711eb0c8fc67b85f9c22b6", null ],
    [ "destroyEntity", "class_ogre_1_1_scene_manager.html#a9238b475a6419e858877bc05de3c3e50", null ],
    [ "destroyItem", "class_ogre_1_1_scene_manager.html#a5fd090b454acb46a228428ec42fc0dfd", null ],
    [ "destroyLight", "class_ogre_1_1_scene_manager.html#acce173aa89e849bda564f4e6e3be6402", null ],
    [ "destroyManualObject", "class_ogre_1_1_scene_manager.html#a75d15c3ac882f78f0001d9d007f403be", null ],
    [ "destroyMovableObject", "class_ogre_1_1_scene_manager.html#a32a135e382bac33ecd42f946713e2f38", null ],
    [ "destroyMovableObject", "class_ogre_1_1_scene_manager.html#a487bf8d2930ebdade5d3ca34c8c6d34e", null ],
    [ "destroyParticleSystem", "class_ogre_1_1_scene_manager.html#abde401fcf3796e3e2beb8c7603648f07", null ],
    [ "destroyQuery", "class_ogre_1_1_scene_manager.html#a08f7adf5f342c6808481fa922c8c62a0", null ],
    [ "destroyRectangle2D", "class_ogre_1_1_scene_manager.html#a50dc6e1a02a65c740e8debda1ef59280", null ],
    [ "destroyRibbonTrail", "class_ogre_1_1_scene_manager.html#a3559e67959d2e5d8ddf10b9e0556e93a", null ],
    [ "destroySceneNode", "class_ogre_1_1_scene_manager.html#aa613e5ffb08b95a90644a61ac10c9b5c", null ],
    [ "destroySkeletonInstance", "class_ogre_1_1_scene_manager.html#a911db15a672db3ebb4837840ed2c5bf0", null ],
    [ "destroyWireAabb", "class_ogre_1_1_scene_manager.html#aa12bb6b0b9cf79cf8aaa1f454cea9116", null ],
    [ "executeUserScalableTask", "class_ogre_1_1_scene_manager.html#a040241bad11b74f5ba8971fb146f8c6d", null ],
    [ "extractAllMovableObjectsByType", "class_ogre_1_1_scene_manager.html#a1c55f5e97c66261de71c979db64f6355", null ],
    [ "extractMovableObject", "class_ogre_1_1_scene_manager.html#a874431ce04c34fa6dcbdb2ed1420b168", null ],
    [ "findCamera", "class_ogre_1_1_scene_manager.html#a6ce996f6c17ae3a2644cf7b480342774", null ],
    [ "findCameraNoThrow", "class_ogre_1_1_scene_manager.html#a2025ed87eaea384815e331dbff5f561b", null ],
    [ "findMovableObjects", "class_ogre_1_1_scene_manager.html#adab6a83be3e4045890ed16dd80023ea7", null ],
    [ "findSceneNodes", "class_ogre_1_1_scene_manager.html#adca3e6a51e42c0f7383f7d92c4a79377", null ],
    [ "getAmbientLightHemisphereDir", "class_ogre_1_1_scene_manager.html#afe7543bcc25f74a609507dfc357d3973", null ],
    [ "getAmbientLightLowerHemisphere", "class_ogre_1_1_scene_manager.html#afec9e0e60b7ebc74d75413ad90d88b1f", null ],
    [ "getAmbientLightUpperHemisphere", "class_ogre_1_1_scene_manager.html#a9a9fc4274bd15279f3eef6d1b908fa88", null ],
    [ "getAnimation", "class_ogre_1_1_scene_manager.html#a0cf942914f681a54cce83bad04906798", null ],
    [ "getAnimationIterator", "class_ogre_1_1_scene_manager.html#a525a0cf8f956d7c3a9ce8ad47cc11ed7", null ],
    [ "getAnimations", "class_ogre_1_1_scene_manager.html#a8c46aaf43efdf676ea590bbec79b514c", null ],
    [ "getAnimationState", "class_ogre_1_1_scene_manager.html#a42e72c9a7dcf9e31f176d6fd69820633", null ],
    [ "getAnimationStateIterator", "class_ogre_1_1_scene_manager.html#ab0360b83e6d67faae01f70ea7b925146", null ],
    [ "getAtmosphere", "class_ogre_1_1_scene_manager.html#aa1aa76d962057bf5dab222e7ddc001f2", null ],
    [ "getAtmosphereRaw", "class_ogre_1_1_scene_manager.html#a8afa979cfab6ba8c0fdeda2f11e28db7", null ],
    [ "getCameraIterator", "class_ogre_1_1_scene_manager.html#a82f2e6f1a388c3b1937039cf0e42c63c", null ],
    [ "getCameras", "class_ogre_1_1_scene_manager.html#ab7d0636b79f0ae7cc2cae4b92c664cc6", null ],
    [ "getCamerasInProgress", "class_ogre_1_1_scene_manager.html#a17f57d1485b6f28bed9a7ead8d59b8e1", null ],
    [ "getCompositorTextures", "class_ogre_1_1_scene_manager.html#a44601dc86e3c7c097554f23711b5833f", null ],
    [ "getCurrentCastersBox", "class_ogre_1_1_scene_manager.html#ab92a5f4d67a07e621d35eadce2932b6a", null ],
    [ "getCurrentCompositorPass", "class_ogre_1_1_scene_manager.html#a024d27a26074b9443ca2ea31bd20d392", null ],
    [ "getCurrentPassDepthTextureNoMsaa", "class_ogre_1_1_scene_manager.html#a385a331e6d36175f40e34380311d9ede", null ],
    [ "getCurrentPrePassDepthTexture", "class_ogre_1_1_scene_manager.html#a2944445939251525c3a89943608d6b7d", null ],
    [ "getCurrentPrePassMode", "class_ogre_1_1_scene_manager.html#a885105ccc1b2916ddb23c6720e49a609", null ],
    [ "getCurrentPrePassTextures", "class_ogre_1_1_scene_manager.html#aefa9a69829ea37baf535bc2f4b71eb26", null ],
    [ "getCurrentRefractionsTexture", "class_ogre_1_1_scene_manager.html#a57b67deedb720db232e078f07331879f", null ],
    [ "getCurrentShadowNode", "class_ogre_1_1_scene_manager.html#a8030c1cbd31c6e683f0c16435bd357ca", null ],
    [ "getCurrentSsrTexture", "class_ogre_1_1_scene_manager.html#aa041d2301aa3c22668b60339468c95f7", null ],
    [ "getCurrentViewport0", "class_ogre_1_1_scene_manager.html#a11d9f44d40c3c8701e44e7f6fd2ba18f", null ],
    [ "getDecalsDiffuse", "class_ogre_1_1_scene_manager.html#aa988feb7450645f788e58fe2f17af8ce", null ],
    [ "getDecalsEmissive", "class_ogre_1_1_scene_manager.html#a54f1a83c0d4abe6eb52f8f73a56dba50", null ],
    [ "getDecalsNormals", "class_ogre_1_1_scene_manager.html#af755f859840603f48bd8d7e573ae128d", null ],
    [ "getDestinationRenderSystem", "class_ogre_1_1_scene_manager.html#a91dee910ef9412d09800e11b4c5f569c", null ],
    [ "getDisplaySceneNodes", "class_ogre_1_1_scene_manager.html#aad6b3b69661d9953a97978263424a65f", null ],
    [ "getDummySceneNode", "class_ogre_1_1_scene_manager.html#a163c2c7aa474ff59c70d93a472758f1f", null ],
    [ "getEnvFeatures", "class_ogre_1_1_scene_manager.html#ad95420a53abc951b1ff614907b43dc3b", null ],
    [ "getFindVisibleObjects", "class_ogre_1_1_scene_manager.html#ae0c73c882ba16527bc9e55498ec59002", null ],
    [ "getFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#ac981c1e86936cdf189150d6dabeb8f4f", null ],
    [ "getForwardPlus", "class_ogre_1_1_scene_manager.html#affa7a4596f373629fcb78519dd66f1ff", null ],
    [ "getGlobalLightList", "class_ogre_1_1_scene_manager.html#a6af13fb4aa57c62802b840ec87e8109c", null ],
    [ "getLightClippingPlanes", "class_ogre_1_1_scene_manager.html#a430db63ba198fcaca82ea94c8e5f0210", null ],
    [ "getLightMask", "class_ogre_1_1_scene_manager.html#acd30d431eb84e9c00d3e3051dfcb7631", null ],
    [ "getLightScissorRect", "class_ogre_1_1_scene_manager.html#aed6fa4bfde15ddcc956bf8d69082064b", null ],
    [ "getMinMaxDepthRange", "class_ogre_1_1_scene_manager.html#a7c3f378c66d1266970320d8fb04278b0", null ],
    [ "getMovableObjectIterator", "class_ogre_1_1_scene_manager.html#af19c32fbc0adc0fa28d8e6c26d9800cb", null ],
    [ "getName", "class_ogre_1_1_scene_manager.html#a62c4a11d535277d361d1ce376675e4d1", null ],
    [ "getNumCompositorTextures", "class_ogre_1_1_scene_manager.html#a4b25cc84294cfccc0e963289521f7b6a", null ],
    [ "getNumWorkerThreads", "class_ogre_1_1_scene_manager.html#a4ac962924e49d9686471e3e639177129", null ],
    [ "getOption", "class_ogre_1_1_scene_manager.html#a2ea53a860f373185f5a46239f579a361", null ],
    [ "getOptionKeys", "class_ogre_1_1_scene_manager.html#a7c8ff6b5c19eb9eeef9d5a6c9fca9fe8", null ],
    [ "getOptionValues", "class_ogre_1_1_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93", null ],
    [ "getRadialDensityMask", "class_ogre_1_1_scene_manager.html#a334459abc4920eb1bdd75bda69f69eb2", null ],
    [ "getRelativeOrigin", "class_ogre_1_1_scene_manager.html#aaa473a1b76a9eb082cfbb31b7390349f", null ],
    [ "getRenderQueue", "class_ogre_1_1_scene_manager.html#ae1dc2f3757619b4abb143f7ad68cff90", null ],
    [ "getRootSceneNode", "class_ogre_1_1_scene_manager.html#acc8c5b44ac2874ca069800378d2705a7", null ],
    [ "getSceneNode", "class_ogre_1_1_scene_manager.html#ae3ac7fea64e00ce827e90b178c6223a9", null ],
    [ "getSceneNode", "class_ogre_1_1_scene_manager.html#a1efb01b456181bff954406a6fb006097", null ],
    [ "getShadowColour", "class_ogre_1_1_scene_manager.html#afb3c2757a3ecb21d4ef193bd5b71bd6d", null ],
    [ "getShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#ad24dc352ecec769b738df9d1612b1202", null ],
    [ "getShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#ad89081c54d3408b72c0cbf7b66917248", null ],
    [ "getShadowFarDistance", "class_ogre_1_1_scene_manager.html#aa1911e4a72e0781ee68225de480ca60c", null ],
    [ "getShadowFarDistanceSquared", "class_ogre_1_1_scene_manager.html#aadc40a279ac50ed638f8fe88ef7358e0", null ],
    [ "getShowBoundingBoxes", "class_ogre_1_1_scene_manager.html#aa6008c82cd40e85f1b1c38d7929ec2ba", null ],
    [ "getSky", "class_ogre_1_1_scene_manager.html#ac19e5e258d60b9546f013c3851553ef1", null ],
    [ "getSkyMaterial", "class_ogre_1_1_scene_manager.html#a5380b5752fbdc38c0476d715f3e963d7", null ],
    [ "getSkyMethod", "class_ogre_1_1_scene_manager.html#ac828cd3ecb5edb1255bd6692b4b4f2f7", null ],
    [ "getSphericalHarmonics", "class_ogre_1_1_scene_manager.html#a45071692da3ff5d2706c2e936c306ba0", null ],
    [ "getSuggestedViewpoint", "class_ogre_1_1_scene_manager.html#add6fe27d7a9500aafbe9325c21985801", null ],
    [ "getTypeName", "class_ogre_1_1_scene_manager.html#a6b9cc60e91cb9e09597f75d8c6a99cce", null ],
    [ "getVisibilityMask", "class_ogre_1_1_scene_manager.html#acb7dd8e3e86102503d4c990433047ad8", null ],
    [ "hasAnimation", "class_ogre_1_1_scene_manager.html#a689e655688df190c38eb3437c7a8e94e", null ],
    [ "hasAnimationState", "class_ogre_1_1_scene_manager.html#affa968418639b742f299cf6cb553aa73", null ],
    [ "hasMovableObject", "class_ogre_1_1_scene_manager.html#a17bf05431cd6901c4b2fc9c89a42de67", null ],
    [ "hasOption", "class_ogre_1_1_scene_manager.html#a6c9731d50869bd17fd55dfbf0f54db78", null ],
    [ "injectMovableObject", "class_ogre_1_1_scene_manager.html#af13eb691a7bdd67e17a402dee98c4b5f", null ],
    [ "isDecalsDiffuseEmissiveMerged", "class_ogre_1_1_scene_manager.html#a026ef6835c39e17cb8a3ab485a653b0b", null ],
    [ "isSkyEnabled", "class_ogre_1_1_scene_manager.html#aca98bc5c9414a63e9e7cd007e2f848ad", null ],
    [ "isUsingInstancedStereo", "class_ogre_1_1_scene_manager.html#a635375da32f1c76624f46b3678ee494d", null ],
    [ "notifyStaticAabbDirty", "class_ogre_1_1_scene_manager.html#a09cefefe52f0a24f5df51d8edc36df25", null ],
    [ "notifyStaticDirty", "class_ogre_1_1_scene_manager.html#a464c4d6f1f2761d8d3b715df0591b96a", null ],
    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a0eefe02b720cef4bee630ab97c6a0125", null ],
    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a5d903e46743ff7af72594b907fc8d04d", null ],
    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a92234d6a25f84cc223c710f3c0724794", null ],
    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a32535513fb44c5a02e41b4e1f38594ec", null ],
    [ "OGRE_DEPRECATED_VER", "class_ogre_1_1_scene_manager.html#a585404a6e220b4d141d8c4e3e0d7bb74", null ],
    [ "OGRE_MUTEX", "class_ogre_1_1_scene_manager.html#a9b10b7fef2893e75acc083415df70446", null ],
    [ "registerSceneNodeListener", "class_ogre_1_1_scene_manager.html#aaff41e7ad0baa4f0aa50f4b3e7048d63", null ],
    [ "removeListener", "class_ogre_1_1_scene_manager.html#a4437b11b78eae8f5db205aa89c0235ee", null ],
    [ "removeLodListener", "class_ogre_1_1_scene_manager.html#a25cc1bb36997b722fc60efc7903f3760", null ],
    [ "removeRenderObjectListener", "class_ogre_1_1_scene_manager.html#a2a482e0a9f78109a5a467ddd6c16082b", null ],
    [ "removeRenderQueueListener", "class_ogre_1_1_scene_manager.html#a190471ba7a61111d576a1e8ca9862706", null ],
    [ "reserveSlotsInGlobalLightList", "class_ogre_1_1_scene_manager.html#aad27e5120c93cbb43fbd3ec31151dfd4", null ],
    [ "setAmbientLight", "class_ogre_1_1_scene_manager.html#a661eec1b30244cf1ff7d334d4ea3cc30", null ],
    [ "setBuildLegacyLightList", "class_ogre_1_1_scene_manager.html#af2ae1a40967ba02a34db40413ba45968", null ],
    [ "setDecalsDiffuse", "class_ogre_1_1_scene_manager.html#a994566fb8e67589ebb8bb81b6442acf5", null ],
    [ "setDecalsEmissive", "class_ogre_1_1_scene_manager.html#a3cd61130767f7f472128a2d80cf9e474", null ],
    [ "setDecalsNormals", "class_ogre_1_1_scene_manager.html#a6641ec14886392ed948edbd21783f1f5", null ],
    [ "setDisplaySceneNodes", "class_ogre_1_1_scene_manager.html#a46c5cbc33b0f498ed01670289e87584c", null ],
    [ "setFindVisibleObjects", "class_ogre_1_1_scene_manager.html#a04c8414da02aec3e3f98acd013917ed2", null ],
    [ "setFlipCullingOnNegativeScale", "class_ogre_1_1_scene_manager.html#a2a4d997503b651187f2e129cd5eeb7ad", null ],
    [ "setFog", "class_ogre_1_1_scene_manager.html#af6a241d39e3a26f31bafcd444481b157", null ],
    [ "setForward3D", "class_ogre_1_1_scene_manager.html#a7b4cbdad7664b8747f1929dbec29c046", null ],
    [ "setForwardClustered", "class_ogre_1_1_scene_manager.html#a4fd7c7abebcd867e462035b32458983a", null ],
    [ "setLightMask", "class_ogre_1_1_scene_manager.html#aafb46b1100b787f2b032407d889251b9", null ],
    [ "setOption", "class_ogre_1_1_scene_manager.html#a34f3ddda75dcf75d5c5176446b3316a8", null ],
    [ "setRadialDensityMask", "class_ogre_1_1_scene_manager.html#ab703066810e23f4284e1662fe58ae8f3", null ],
    [ "setRelativeOrigin", "class_ogre_1_1_scene_manager.html#a3ee0d5d307652b51bc7a405907a85368", null ],
    [ "setShadowColour", "class_ogre_1_1_scene_manager.html#ad8ab6139696f9ef50d8abea0528e85b4", null ],
    [ "setShadowDirectionalLightExtrusionDistance", "class_ogre_1_1_scene_manager.html#a9d220fa31bf0d95ad65558936c71a194", null ],
    [ "setShadowDirLightTextureOffset", "class_ogre_1_1_scene_manager.html#a893663f55c2b4a29467cff25b9b1b3f4", null ],
    [ "setShadowFarDistance", "class_ogre_1_1_scene_manager.html#a0e593d05e2f892b8fc3bfca917a75fef", null ],
    [ "setShadowTextureFadeEnd", "class_ogre_1_1_scene_manager.html#a237a09e65919b808473c543fb886723f", null ],
    [ "setShadowTextureFadeStart", "class_ogre_1_1_scene_manager.html#a72fa019aa4efbc6943842efcf5f38078", null ],
    [ "setSky", "class_ogre_1_1_scene_manager.html#a3dc2f4478ab8741bdcf02c9008ef7809", null ],
    [ "setSky", "class_ogre_1_1_scene_manager.html#ab8c1c6962ad94e28ac4a202f1fd16772", null ],
    [ "setSphericalHarmonics", "class_ogre_1_1_scene_manager.html#a5447c974f3384f0b7550a2f776a25b28", null ],
    [ "setVisibilityMask", "class_ogre_1_1_scene_manager.html#a7c5e69ee25b1e34eadd088d7d58ef02d", null ],
    [ "showBoundingBoxes", "class_ogre_1_1_scene_manager.html#a487859007d68fe9f261aea1645252563", null ],
    [ "shrinkToFitMemoryPools", "class_ogre_1_1_scene_manager.html#a1466e16a5ce667fea5765d67e4654287", null ],
    [ "unregisterSceneNodeListener", "class_ogre_1_1_scene_manager.html#ac660da6d88e53b19c0062884705222ca", null ],
    [ "updateAllAnimations", "class_ogre_1_1_scene_manager.html#a393dbe126bfaaf7f5aa4712a84d3facd", null ],
    [ "updateAllBounds", "class_ogre_1_1_scene_manager.html#a5de4ecb4955dcf164cfeb69c457716ee", null ],
    [ "updateAllLods", "class_ogre_1_1_scene_manager.html#a77ce1584abf7edd2896e7f7c0d0bd629", null ],
    [ "updateAllTagPoints", "class_ogre_1_1_scene_manager.html#a8612bb2ff02cf6e5ff976ebbdd392921", null ],
    [ "updateAllTransforms", "class_ogre_1_1_scene_manager.html#a1f59ebdfaadbe33f713d754737041654", null ],
    [ "updateSceneGraph", "class_ogre_1_1_scene_manager.html#a3cbd2750082529aed2375531a4d5d9cd", null ],
    [ "waitForPendingUserScalableTask", "class_ogre_1_1_scene_manager.html#a11c832526246a71e73cd517bff928a64", null ],
    [ "QUERY_ENTITY_DEFAULT_MASK", "class_ogre_1_1_scene_manager.html#a6c140ffaced93a2b854e5c519c8fb568", null ],
    [ "QUERY_FRUSTUM_DEFAULT_MASK", "class_ogre_1_1_scene_manager.html#a6617d4f358cbe1d72edd06b7a8ad62bd", null ],
    [ "QUERY_FX_DEFAULT_MASK", "class_ogre_1_1_scene_manager.html#a412b439c03cb282ee205498d9b00220e", null ],
    [ "QUERY_LIGHT_DEFAULT_MASK", "class_ogre_1_1_scene_manager.html#a9d2789c7eea005fd7c63b3ee3b850617", null ],
    [ "QUERY_STATICGEOMETRY_DEFAULT_MASK", "class_ogre_1_1_scene_manager.html#a09844d40f3b7404e591224b814067e63", null ]
];